@@ -6,8 +6,12 @@ function (x, quan = 1/2, alpha = 0.025) {
 # Part of the ChemoSpec Package
 # Bryan Hanson, DePauw University, Aug 2009
 
+	if (!requireNamespace("robustbase", quietly = TRUE)) {
+		stop("You need to install package robustbase to use this function")
+	}
+
 	x <- as.matrix(x)
-    covr <- covMcd(x, cor = TRUE, alpha = quan)
+    covr <- robustbase::covMcd(x, cor = TRUE, alpha = quan)
     cov.svd <- svd(cov(x), nv = 0)
     covr.svd <- svd(covr$cov, nv = 0)
     r <- cov.svd[["u"]] %*% diag(sqrt(cov.svd[["d"]]))
