@@ -1,5 +1,9 @@
 r_pcaSpectra <-
 function(spectra, choice = "noscale") {
+
+	if (!requireNamespace("pcaPP", quietly = TRUE)) {
+		stop("You need to install package pcaPP to use this function")
+	}
 	
 	if (missing(spectra)) stop("No spectral data set provided")
 	chkSpectra(spectra)
@@ -13,7 +17,7 @@ function(spectra, choice = "noscale") {
 	
 	note <- choice
 	if (choice == "noscale") choice <- NULL
-	pca <- PCAgrid(spectra$data, k = 10, scale = choice, scores = TRUE)
+	pca <- pcaPP::PCAgrid(spectra$data, k = 10, scale = choice, scores = TRUE)
 	pca$method <- paste("l1median/", note, "/", "robust", sep = "")
 	pca <- r2qPCA(pca) # convert classes
 	}
