@@ -17,40 +17,44 @@ function(spectra, method = c("sd", "sem", "sem95", "mad", "iqr"),
 	if (method == "iqr"){
 		y <- aaply(spectra$data, 2, seXyIqr)
 		y <- y[,3] - y[,2]
-		lab <- "relative iqr"
+		lab <- "iqr"
 		}
 
 	if (method == "sd") {
 		y <- aaply(spectra$data, 2, sd)
-		lab <- "relative sd"
+		lab <- "sd"
 		}
 
 	if (method == "sem") {
 		y <- aaply(spectra$data, 2, seXy)
 		y <- y[,3] - y[,2]
-		lab <- "relative sem"
+		lab <- "sem"
 		}
 
 	if (method == "mad") {
 		y <- aaply(spectra$data, 2, seXyMad)
 		y <- y[,3] - y[,2]
-		lab <- "relative mad"
+		lab <- "mad"
 		}
 
 	if (method == "sem95") {
 		y <- aaply(spectra$data, 2, seXy95)
 		y <- y[,3] - y[,2]
-		lab <- "relative sem95"
+		lab <- "sem95"
 		}
 
-	# Now plot
+	# Now set up the plot and plot it!
+	
 	M <- rbind(M, y)
 	ymax <- max(M)
-	# offset the summary stat below everything else, with a small gap for aesthetics
+	
+	# Offset the summary stat below everything else, with a small gap for aesthetics
+	
 	off1 <- diff(range(y))
 	off2 <- min(M) - 0.05*diff(range(M))
 	ymin <- off2 - off1
 	off3 <- abs(min(M)) + abs(max(y)) + abs(0.05*diff(range(M)))
+	
 	plot(x, M[1,], type = "n", ylim = c(ymin, ymax), xlab = spectra$unit[1], ylab = "Centered Spectra", ...)
 	for (i in 1:(nrow(M)-1)) {
 		lines(x, M[i,], col = spectra$colors[i])
